Crate tree_sitter_preproc_code_split

Crate tree_sitter_preproc_code_split 

This crate provides Preproc grammar support for the tree-sitter parsing library.

Typically, you will use the LANGUAGE constant to add this grammar to a tree-sitter Parser, and then use the parser to parse some code:

use tree_sitter::Parser;

let code = r#"
    int double(int x) {
        return x * 2;
    }
"#;
let mut parser = Parser::new();
let language = tree_sitter_preproc::LANGUAGE;
parser
    .set_language(&language.into())
    .expect("Error loading Preproc parser");
let tree = parser.parse(code, None).unwrap();
assert!(!tree.root_node().has_error());

Constants

GRAMMAR
The source of the Preproc tree-sitter grammar description.
LANGUAGE
The tree-sitter LanguageFn for this grammar.
NODE_TYPES
The content of the node-types.json file for this grammar.